=======================
 Invenio-Groups v0.1.3
=======================

Invenio-Groups v0.1.3 was released on September 7, 2015.

About
-----

Invenio module that adds support for user groups.

*This is an experimental developer preview release.*

Improved features
-----------------

- Adds space between icons and text within buttons. This follows the
  bootstrap design guidelines and makes it more consistent with the
  rest of Invenio.

Bug fixes
---------

- Reintegrates permission checks after module rewrite. (#17) (#19)

Installation
------------

   $ pip install invenio-groups==0.1.3

Documentation
-------------

   http://invenio-groups.readthedocs.org/en/v0.1.3

Happy hacking and thanks for flying Invenio-Groups.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-groups
|   URL: http://invenio-software.org
